@@ -33,6 +33,7 @@ OC.L10N.register(
     "An error occurred, unable to change visibility of the calendar." : "C'hoarvezet ez eus ur fazi, ne c'halletr ket kemmañ gweluster an deiziataer.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Paouezet e vo da lodañ an deiziataer a-benn {countdown} eilenn"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dilamet e vo an deiziataer a-benn {countdown} eilenn"],
+    "Calendars" : "Deiziadurioù",
     "New calendar" : "Deizataer nevez",
     "Creating calendar …" : "Krouiñ un deizataer ...",
     "New calendar with task list" : "Deizataer nevez gant ur roll ober",
@@ -50,6 +51,7 @@ OC.L10N.register(
     "Deleted" : "Lamet",
     "Restore" : "Adkrouiñ",
     "Delete permanently" : "Lamet da viken",
+    "Empty trash bin" : "Pod-lastez goullo",
     "Could not update calendar order." : "Dibosupl eo adnevesaat urzh an deizataerioù",
     "Share link" : "Lodañ al liamm",
     "Copy public link" : "Eilañ al liamm foran",
@@ -91,7 +93,7 @@ OC.L10N.register(
     "Monday" : "Lun",
     "Update" : "Hizivaat",
     "Your email address" : "O chom-lec'h postel",
-    "Notification" : "Kemenadenn",
+    "Notification" : "Kemennadenn",
     "Email" : "Postel",
     "Delete file" : "Dilemel ar restr",
     "Available" : "Vak",
