@@ -13,6 +13,7 @@ OC.L10N.register(
     "Calendar" : "Kalendaro",
     "New booking {booking}" : "Nova rezervo {booking}",
     "Confirm" : "Konfirmi",
+    "Description:" : "Priskribo:",
     "Date:" : "Dato:",
     "Where:" : "Kie:",
     "Comment:" : "Komento:",
@@ -34,6 +35,8 @@ OC.L10N.register(
     "Restore" : "Restaŭri",
     "Delete permanently" : "Forigi por ĉiam",
     "Empty trash bin" : "Malpleni rubujon",
+    "Deck" : "Kartaro",
+    "Hidden" : "Nevidebla",
     "Internal link" : "Interna ligilo",
     "Share link" : "Kunhavigi ligilon",
     "Delete share link" : "Forigi kunhavo-ligilon",
