@@ -8,6 +8,7 @@ OC.L10N.register(
     "Cheers!" : "¡Saludos!",
     "Calendar" : "Calendario",
     "Confirm" : "Confirmar",
+    "Description:" : "Descripción:",
     "Where:" : "Dónde:",
     "Today" : "Hoy",
     "Day" : "Día",
@@ -24,6 +25,8 @@ OC.L10N.register(
     "Deleted" : "Borrado",
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
+    "Deck" : "Deck",
+    "Hidden" : "Oculto",
     "Share link" : "Compartir liga",
     "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
