@@ -8,6 +8,7 @@ OC.L10N.register(
     "Calendar" : "Calendièr",
     "Appointments" : "Rendetz-vos",
     "Confirm" : "Confirmar",
+    "Description:" : "Descripcion :",
     "Date:" : "Data :",
     "Where:" : "Ont :",
     "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
@@ -29,6 +30,7 @@ OC.L10N.register(
     "Delete" : "Suprimir",
     "Add new" : "Apondre novèl",
     "Untitled calendar" : "Calendièr sens nom",
+    "Calendars" : "Calendièrs",
     "New calendar" : "Calendièr novèl",
     "Name for new calendar" : "Nom del calendièr novèl",
     "Creating calendar …" : "Creacion del calendièr…",
@@ -38,6 +40,7 @@ OC.L10N.register(
     "Deleted" : "Suprimit",
     "Restore" : "Restaurar",
     "Delete permanently" : "Suprimir definitivament",
+    "Hidden" : "Amagat",
     "Share link" : "Partejar lo ligam",
     "Copy public link" : "Copiar lo ligam public",
     "Copied code" : "Còdi copiat",
@@ -99,6 +102,7 @@ OC.L10N.register(
     "Busy" : "Ocupat",
     "Out of office" : "Fòra del burèu",
     "Unknown" : "Desconegut",
+    "Room name" : "Nom de la sala",
     "Accept" : "Acceptar",
     "Decline" : "Declinar",
     "Tentative" : "Provisòri",
